@@ -175,8 +175,7 @@ void KMailMigrator::migrate()
   deleteOldGroup();
   migrateTags();
   migrateRCFiles();
-  migrateNotifyFile();
-  
+
   // copy autosave files if there are any
   const QString autoSaveDir = KGlobal::dirs()->saveLocation( "data", "kmail/autosave", false );
   if ( !autoSaveDir.isEmpty() ) {
@@ -219,15 +218,6 @@ void KMailMigrator::deleteOldGroup( const QString& name ) {
   }
 }
 
-void KMailMigrator::migrateNotifyFile()
-{
-    const QString notifyFile = KStandardDirs::locate( "config", "kmail.notifyrc" );
-    if ( !notifyFile.isEmpty() ) {
-        QFile::copy( notifyFile, KStandardDirs::locateLocal("config", "kmail2.notifyrc"));
-    }
-
-}
-
 void KMailMigrator::migrateTags()
 {
   KConfigGroup tagMigrationConfig( KGlobal::config(), QLatin1String( "MessageTags" ) );
