@@ -18,7 +18,6 @@
 */
 
 #include "akonadi_serializer_kcalcore.h"
-#include "config-kcalcore.h"
 
 #include <akonadi/abstractdifferencesreporter.h>
 #include <akonadi/item.h>
@@ -70,11 +69,7 @@ void SerializerPluginKCalCore::serialize(const Item & item, const QByteArray & l
   Incidence::Ptr i = item.payload<Incidence::Ptr>();
   // ### I guess this can be done without hardcoding stuff
   data.write( "BEGIN:VCALENDAR\nPRODID:-//K Desktop Environment//NONSGML libkcal 3.2//EN\nVERSION:2.0\n" );
-#ifdef HAVE_TORAWSTRING
   data.write( mFormat.toRawString( i ) );
-#else
-  data.write( mFormat.toString( i ).toUtf8() );
-#endif
   data.write( "\nEND:VCALENDAR" );
 }
 
