@@ -46,7 +46,7 @@
 #else
 #include <QtGui/QListView>
 #include <QtGui/QSortFilterProxyModel>
-#include "kdescendantsproxymodel_p.h"
+#include <kdescendantsproxymodel.h>
 
 class CheckableFilterProxyModel : public QSortFilterProxyModel
 {
@@ -260,6 +260,7 @@ void SubscriptionDialog::onFullListingDone( KJob *job )
 void SubscriptionDialog::onSubscribedMailBoxesReceived( const QList<KIMAP::MailBoxDescriptor> &mailBoxes,
                                                         const QList< QList<QByteArray> > &flags )
 {
+  Q_UNUSED( flags );
   for ( int i = 0; i<mailBoxes.size(); i++ ) {
     KIMAP::MailBoxDescriptor mailBox = mailBoxes[i];
     QString descriptor = mailBox.separator + mailBox.name;
@@ -274,6 +275,7 @@ void SubscriptionDialog::onSubscribedMailBoxesReceived( const QList<KIMAP::MailB
 
 void SubscriptionDialog::onReloadDone( KJob *job )
 {
+  Q_UNUSED( job );
   enableButton( User1, true );
 }
 
