@@ -83,7 +83,8 @@ void KCalResource::configure( WId windowId )
     emit status( Running,
                  i18nc( "@info:status", "Changing calendar plugin configuration" ) );
     KRES::ConfigDialog dlg( 0, QLatin1String( "calendar" ), mResource );
-    KWindowSystem::setMainWindow( &dlg, windowId );
+    if( windowId ) 
+      KWindowSystem::setMainWindow( &dlg, windowId );
     if ( dlg.exec() ) {
       setName( mResource->resourceName() );
       mManager->writeConfig( KGlobal::config().data() );
@@ -513,9 +514,9 @@ bool KCalResource::openConfiguration()
              this, SLOT( initialLoadingFinished( ResourceCalendar* ) ) );
     connect( mResource, SIGNAL( resourceLoadError( ResourceCalendar*, const QString& ) ),
              this, SLOT( loadingError( ResourceCalendar*, const QString& ) ) );
-  }
 
   setName( mResource->resourceName() );
+  }
 
   return true;
 }
@@ -623,6 +624,7 @@ void KCalResource::reloadConfig()
 
 void KCalResource::initialLoadingFinished( ResourceCalendar *resource )
 {
+  Q_UNUSED( resource );
   Q_ASSERT( resource == mResource );
 
   kDebug();
@@ -640,6 +642,7 @@ void KCalResource::initialLoadingFinished( ResourceCalendar *resource )
 
 void KCalResource::resourceChanged( ResourceCalendar *resource )
 {
+  Q_UNUSED( resource );
   Q_ASSERT( resource == mResource );
 
   kDebug();
@@ -655,6 +658,7 @@ void KCalResource::resourceChanged( ResourceCalendar *resource )
 
 void KCalResource::loadingError( ResourceCalendar *resource, const QString &message )
 {
+  Q_UNUSED( resource );
   Q_ASSERT( resource == mResource );
 
   kError() << "Loading error: " << message;
@@ -667,6 +671,7 @@ void KCalResource::loadingError( ResourceCalendar *resource, const QString &mess
 
 void KCalResource::savingError( ResourceCalendar *resource, const QString &message )
 {
+  Q_UNUSED( resource );
   Q_ASSERT( resource == mResource );
 
   kError() << "Saving error: " << message;
