@@ -19,6 +19,7 @@
 
 #include "maildir.h"
 
+#include <QDateTime>
 #include <QDir>
 #include <QFileInfo>
 #include <QUuid>
@@ -324,6 +325,20 @@ Maildir Maildir::subFolder( const QString& subFolder ) const
     return Maildir();
 }
 
+Maildir Maildir::parent() const
+{
+  if ( !isValid() || d->isRoot )
+    return Maildir();
+  QDir dir( d->path );
+  dir.cdUp();
+  if ( !dir.dirName().startsWith( '.' ) || !dir.dirName().endsWith( QLatin1String(".directory") ) )
+    return Maildir();
+  const QString parentName = dir.dirName().mid( 1, dir.dirName().size() - 11 );
+  dir.cdUp();
+  dir.cd( parentName );
+  return Maildir ( dir.path() );
+}
+
 QStringList Maildir::entryList() const
 {
     QStringList result;
@@ -389,6 +404,21 @@ qint64 Maildir::size( const QString& key ) const
     return info.size();
 }
 
+QDateTime Maildir::lastModified(const QString& key) const
+{
+    const QString realKey( d->findRealKey( key ) );
+    if ( realKey.isEmpty() ) {
+        qWarning() << "Maildir::lastModified unable to find: " << key;
+        return QDateTime();
+    }
+
+    const QFileInfo info( realKey );
+    if ( !info.exists() )
+        return QDateTime();
+
+    return info.lastModified();
+}
+
 QByteArray Maildir::readEntryHeaders( const QString& key ) const
 {
     QByteArray result;
