@@ -26,6 +26,8 @@
 #include <QString>
 #include <QStringList>
 
+class QDateTime;
+
 namespace KPIM {
 
 class MAILDIR_EXPORT Maildir
@@ -115,12 +117,23 @@ public:
      */
     Maildir subFolder( const QString& folderName ) const;
 
+    /**
+     * Returns the parent Maildir object for this Maildir, if there is one (ie. this is not the root).
+     */
+    Maildir parent() const;
+
     /**
      * Returns the size of the file in the maildir with the given @p key.
      * @since 4.2
      */
     qint64 size( const QString& key ) const;
 
+    /**
+     * Returns the modification time of the file in the maildir with the given @p key.
+     * @since 4.7
+     */
+    QDateTime lastModified( const QString &key ) const;
+
     /**
      * Return the contents of the file in the maildir with the given @p key.
      */
